﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using System.Linq;

namespace KuduRestClient
{
    class KuduClient
    {
        CookieContainer _cookies;
        HttpClient _httpClient;
        string _baseUrl;
        string _basicAuth;

        public KuduClient(string siteName, string userAccount, string userPassword)
        {
            HttpClientHandler handler = new HttpClientHandler();
            _cookies = new CookieContainer();
            handler.CookieContainer = _cookies;

            HttpClient hc = new HttpClient(handler);
            _httpClient = hc;

            _basicAuth = string.Format("Basic {0}", ToBase64(userAccount + ":" + userPassword));
            _httpClient.DefaultRequestHeaders.Add("Authorization", _basicAuth);

            _baseUrl = $"https://{siteName}.scm.azurewebsites.net/";
        }

        private string ToBase64(string text)
        {
            byte [] buf = Encoding.ASCII.GetBytes(text);
            return Convert.ToBase64String(buf);
        }

        public async Task<ScmInfo> GetScmInfoAsync()
        {
            string url = $"{_baseUrl}api/scm/info";

            string text = await _httpClient.GetStringAsync(url);
            return JsonConvert.DeserializeObject<ScmInfo>(text);
        }

        public async Task<List<VfsFile>> GetFileListAsync(string directory)
        {
            string url = $"{_baseUrl}api/vfs/{directory}/";
            string text = await _httpClient.GetStringAsync(url);

            List<VfsFile> files = new List<VfsFile>();
            files.AddRange(JsonConvert.DeserializeObject<VfsFile[]>(text).Where ( (item) => item.mime != "inode/directory") );

            return files;
        }

        public async Task<string> GetFileAsStringAsync(VfsFile file)
        {
            return await _httpClient.GetStringAsync(file.href);
        }

        public async Task<FileContent> GetFileWithEtagAsync(VfsFile file)
        {
            HttpResponseMessage hrm = await _httpClient.GetAsync(file.href);
            hrm.Headers.TryGetValues("ETag", out var values);

            FileContent fc = new FileContent();

            fc.etag = values.FirstOrDefault();
            if (fc.etag != null)
            {
                fc.etag = fc.etag.Trim('\"');
            }

            fc.text = await hrm.Content.ReadAsStringAsync();

            return fc;
        }

        public async Task<bool> DeleteFileAsync(VfsFile file, string etag = "*")
        {
            _httpClient.DefaultRequestHeaders.Add("If-Match", "*");

            HttpResponseMessage hrm = await _httpClient.DeleteAsync(file.href);

            string text = await hrm.Content.ReadAsStringAsync();
            MessageResponse mr = JsonConvert.DeserializeObject<MessageResponse>(text);
            return hrm.StatusCode == HttpStatusCode.OK;
        }
    }
}
