﻿using System;
using System.IO;
using System.Threading.Tasks;

namespace KuduRestClient
{
    class Program
    {
        public static async Task<int> Main(string[] args)
        {
            (string account, string password) = GetAccountInfo();

            if (string.IsNullOrEmpty(account) || string.IsNullOrEmpty(password))
            {
                Console.WriteLine("Account info is null");
                return 1;
            }

            KuduClient client = new KuduClient("[...sitename...]", account, password);

            ScmInfo scmInfo = await client.GetScmInfoAsync();
            Console.WriteLine(scmInfo.GitUrl);

            foreach (VfsFile file in await client.GetFileListAsync("LogFiles/Transform"))
            {
                Console.WriteLine(file.path);

                if (IfLogFiles(file.name))
                {
                    Console.WriteLine($"Deleted: {file.name} - " + await client.DeleteFileAsync(file));
                }
                else
                {
                    FileContent fc = await client.GetFileWithEtagAsync(file);
                    Console.WriteLine($"Deleted: {file.name} - " + await client.DeleteFileAsync(file, fc.etag));
                }
            }

            return 0;
        }

        private static bool IfLogFiles(string name)
        {
            string ext = Path.GetExtension(name);

            switch (ext)
            {
                case ".xml":
                case ".log":
                case ".txt":
                    return true;
            }

            return false;
        }

        private static (string account, string password) GetAccountInfo()
        {
            string[] lines = null;
            (string account, string password) result = (null, null);

            try
            {
                lines = File.ReadAllLines(@"c:\temp\azure.[...sitename...].publish.txt");
                result.account = lines[0];
                result.password = lines[1];
            } catch { }

            return result;
        }
    }
}
